@@ -1,10 +1,10 @@
 from . import v1
 from . import v2
-from .server import run_simple, create_app
+from .server import run_simple, make_app, create_app
 
 __author__ = """Yossi Mosbacher"""
 __email__ = 'joe.mosbacher@gmail.com'
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 
 VERSIONS = {
     "v1": v1,
